@@ -16,6 +16,7 @@ from hcube.api.models.filters import (
 from hcube.api.models.ordering import OrderDirection, OrderSpec
 from hcube.api.models.query import CubeQuery
 from hcube.api.models.transforms import ExplicitMappingTransform
+from hcube.settings import GlobalSettings
 
 
 class NaiveCubeBackend(CubeBackend):
@@ -83,6 +84,9 @@ class NaiveCubeBackend(CubeBackend):
             ret = ret[: query.limit]
         return ret
 
+    def get_count(self, query: CubeQuery) -> int:
+        return len(list(self.get_records(query)))
+
     def delete_records(self, query: CubeQuery) -> None:
         new_records = []
         for record in self.values:
@@ -147,4 +151,4 @@ class NaiveCubeBackend(CubeBackend):
     def _empty_value(cls, op: AggregationOp):
         if op in (AggregationOp.COUNT,):
             return 0
-        return None
+        return 0 if GlobalSettings.aggregates_zero_for_empty_data else None
